@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: dns
-version: 2.0.1
-id: dns-2.0.1-66ef012d91e4b87b664e180d9494a940
-key: dns_I20V4qQwP39B1l2U29XLhg
+version: 2.0.2
+id: dns-2.0.2-5e4d4e169145c1621c42b290ae390f49
+key: dns_ENFhUugr5jI93Dy7QF38Rf
 license: BSD3
 maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
 synopsis: DNS library in Haskell
@@ -19,24 +19,24 @@ exposed-modules:
     Network.DNS.Decode
 hidden-modules: Network.DNS.Internal Network.DNS.StateBinary
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/dns-2.0.1
-hs-libraries: HSdns-2.0.1-I20V4qQwP39B1l2U29XLhg
+import-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/dns-2.0.2
+hs-libraries: HSdns-2.0.2-ENFhUugr5jI93Dy7QF38Rf
 depends:
     attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.13.1-9eaf94b1885f7c12e1eeebbc86766f62
+    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
+    conduit-extra-1.1.13.1-49d5b7e57d33a6d70b83744864ccf557
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
 haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
 haddock-html: /usr/share/doc/haskell-dns/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
